@@ -10,28 +10,28 @@ function zmq_version {
     )
 }
 
-function buildzmq {
-    version="$1"
-    tmpdir=`mktemp -d`
-    if [[ "$version" == "libzmq" ]]; then
-        git clone "https://github.com/zeromq/libzmq.git" $tmpdir
-    else
-        git clone "https://github.com/zeromq/zeromq${version}.git" $tmpdir
+# This assumes libzmqs have been installed to
+# ~/.zmq-ffi/usr/<zmq_version>/lib/libzmq.so, e.g.
+# ~/.zmq-ffi/usr/zeromq2-x/lib/libzmq.so. A docker testing environment is
+# provided that sets this up according, see the BUILD section in the readme
+function get_ld_dir {
+    libzmq_dir="$HOME/.zmq-ffi/usr/$1/lib"
+
+    if test -z "$libzmq_dir/libzmq.so"; then
+        echo "No libzmq.so found in $libzmq_dir" >&2
+        exit 1
     fi
-    ( cd $tmpdir
-        ./autogen.sh
-        ./configure --without-libsodium
-        make -j2 )
-    export LD_LIBRARY_PATH=$tmpdir/src/.libs
+
+    echo "$libzmq_dir"
 }
 
 function local_test {
     test_version=$1
 
     if [[ "$test_version" == "libzmq" ]]; then
-        export LD_LIBRARY_PATH="$HOME/git/libzmq/src/.libs"
+        export LD_LIBRARY_PATH="$(get_ld_dir libzmq)"
     else
-        export LD_LIBRARY_PATH="$HOME/git/zeromq$test_version/src/.libs"
+        export LD_LIBRARY_PATH="$(get_ld_dir zeromq$test_version)"
     fi
 
     echo -e "\nTesting zeromq" \
@@ -61,8 +61,8 @@ do
 done
 
 # extra test to verify sonames arg is honored
-LD_LIBRARY_PATH="$HOME/git/zeromq2-x/src/.libs:"
-LD_LIBRARY_PATH+="$HOME/git/zeromq3-x/src/.libs:"
+LD_LIBRARY_PATH="$(get_ld_dir zeromq2-x)"
+LD_LIBRARY_PATH+=":$(get_ld_dir zeromq3-x)"
 export LD_LIBRARY_PATH
 
 PERL5LIB=lib:$PERL5LIB perl xt/sonames.pl
